Admin index
<a href="{{ url_for('page', name='I løvë Unicode') }}">Unicode test</a>
<a href="{{ url_for('page', name='octothorp', query_foo='bar',
                    _anchor='introduction') }}">URL parsing test</a>
